Crate kcr_cluster_clusterpedia_io

Crate kcr_cluster_clusterpedia_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the cluster.clusterpedia.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

cluster.clusterpedia.io/v1alpha2

  • ClusterSyncResources
  • PediaCluster

Modules

v1alpha2