This crate contains kube-rs compatible bindings for Kubernetes custom resources for the cluster.clusterpedia.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
cluster.clusterpedia.io/v1alpha2
ClusterSyncResourcesPediaCluster